@@ -64,8 +64,9 @@
 #' @param round If \code{TRUE} the \dQuote{shape} of \dQuote{tiles} and \dQuote{cards}
 #'              will be \dQuote{roundrect} instead of \dQuote{rect} (the default).
 #' @param pawn If \code{"token"} (default) the piecepack pawn will be a two-sided token in a \dQuote{halma} outline,
-#'             if \code{"peg-doll"} the piecepack pawn will be a \dQuote{peg doll} style pawn
-#'             (doesn't works well with \code{grid.piece}).
+#'             if \code{"peg-doll"} the piecepack pawn will be a \dQuote{peg doll} style pawn, and
+#'             if \code{"joystick"} the piecepack pawn will be a \dQuote{joystick} style pawn.
+#'             Note for the latter two pawn styles only \code{pawn_top} will work with \code{grid.piece}.
 #' @param cfg List of configuration options
 #' @examples
 #'        cfgs <- game_systems()
@@ -99,88 +100,57 @@
 #'     }
 #' @seealso \code{\link{pp_cfg}} for information about the \code{pp_cfg} objects returned by \code{game_systems}.
 #' @export
-game_systems <- function(style=NULL, round = FALSE, pawn="token") {
+game_systems <- function(style = NULL, round = FALSE, pawn = "token") {
     styles <- c("dejavu", "dejavu3d", "sans", "sans3d")
     if (!is.null(style) && is.na(match(style, styles))) {
         stop(paste("Don't have a customized configuration for style", style))
     }
-    if (is.null(style)) style <- "sans"
+    style <- style %||% "sans"
     is_3d <- grepl("3d$", style)
     rect_shape <- ifelse(round, "roundrect", "rect")
-    if (grepl("^sans", style)) {
-        piecepack_suits <- list(suit_text="\u263c,\u25d8,\u0238,\u03ee,\u2202")
-        pce_suit_text <- "\u2665,\u2660,\u2663,\u2666,\u2202"
-        pc_suit_text <- list(suit_text="\u2665,\u2660,\u2663,\u2666,*",
-                             suit_cex.s5=1.3)
-        face_labels <- c("", "\u050a", "\u046a", "\u0238")
-        chess_black <- c("p", "n", "b", "r", "q", "k")
-        chess_white <- c("P", "N", "B", "R", "Q", "K")
-    } else if (grepl("^dejavu", style)) {
-        piecepack_suits <- list(suit_text="\u2742,\u25d0,\u265b,\u269c,\u0ed1",
-                                suit_cex.s2=0.9, dm_cex.coin=0.5, fontfamily="DejaVu Sans")
-        pce_suit_text <- "\u2665,\u2660,\u2663,\u2666,\u0ed1"
-        pc_suit_text <- list(suit_text="\u2665,\u2660,\u2663,\u2666,\u2605")
-        face_labels <- c("", "\u265e", "\u265b", "\u265a")
-        chess_black <- c("\u265f", "\u265e", "\u265d", "\u265c", "\u265b", "\u265a")
-        chess_white <- c("\u2659", "\u2658", "\u2657", "\u2656", "\u2655", "\u2654")
-    }
-    if (pawn == "peg-doll") {
-        pawn <- list(width.pawn=0.75, depth.pawn=0.75, height.pawn=1.5,
-                     edge_color.pawn=cb_suit_colors_pure,
-                     edge_color.s4.pawn="#0072B2",
-                     background_color.belt_face="white",
-                     mat_color.belt_face="transparent",
-                     suit_cex.belt_face=1.5,
-                     obj_fn.pawn=save_peg_doll_obj)
-    } else {
-        pawn <- NULL
-    }
     if (is_3d) {
-        style_3d <- list(suit_color.s4 = "#0072B2",
-                         invert_colors.pawn = TRUE,
-                         invert_colors.die = TRUE,
-                         background_color.die = "white",
-                         border_color="transparent",
-                         mat_color.tile_back = "burlywood",
-                         edge_color.tile = "black", edge_color.coin = "black")
         color_list <- list(background_color="burlywood",
                            suit_color = cb_suit_colors_pure,
                            border_color = "transparent", border_lex = 0,
                            edge_color.board = "black")
     } else {
-        style_3d <- NULL
         color_list <- list(background_color="white",
                            suit_color = cb_suit_colors_impure,
                            border_color = "black", border_lex = 4,
                            edge_color.board = "white")
     }
-    piecepack_base <- list(depth.coin=0.25,
-                           invert_colors.matchstick = TRUE,
-                           ps_cex.r2.matchstick = 0.7,
-                           dm_r.r1.matchstick = 0, dm_cex.r1.matchstick = 1.5, suit_color.s2.matchstick = "grey30",
-                           mat_color.tile_back="white", mat_width.tile_back=0.05, suit_color.unsuited="black",
-                           invert_colors.bit = TRUE,
-                           rank_text=",a,2,3,4,5",
-                           use_suit_as_ace=TRUE,
-                           shape.tile = rect_shape, shape.card = rect_shape)
-    piecepack <- c(pawn, style_3d, piecepack_suits, color_list, piecepack_base)
 
-    playing_cards_expansion <- piecepack
-    playing_cards_expansion$suit_text <- pce_suit_text
-    playing_cards_expansion$suit_color <- "#D55E00,#000000,#000000,#D55E00,#000000"
+    cards <- playing_cards(style, rect_shape)
+    packs <- piecepack(style, color_list, rect_shape, pawn)
 
-    hexpack <- c(piecepack, list(shape.tile="convex6", border_lex=3,
-                                 shape_t.tile="60",  dm_t.tile_face=-90,
-                                 width.tile=4/sqrt(3), height.tile=4/sqrt(3),
-                                 shape.coin="convex3"))
+    list(checkers1 = checkers(1, color_list),
+         checkers2 = checkers(2, color_list),
+         chess1 = chess(style, 1, color_list),
+         chess2 = chess(style, 2, color_list),
+         dice = dice(color_list, rect_shape),
+         dominoes = dominoes(color_list$suit_color[6], "black", color_list$border_color, rect_shape),
+         dominoes_black = dominoes(color_list$suit_color[2], "white", color_list$border_color, rect_shape),
+         dominoes_blue = dominoes(color_list$suit_color[4], "white", color_list$border_color, rect_shape),
+         dominoes_green = dominoes(color_list$suit_color[3], "white", color_list$border_color, rect_shape),
+         dominoes_red = dominoes(color_list$suit_color[1], "white", color_list$border_color, rect_shape),
+         dominoes_white = dominoes(color_list$suit_color[6], "black", color_list$border_color, rect_shape),
+         dominoes_yellow = dominoes(color_list$suit_color[5], "black", color_list$border_color, rect_shape),
+         dual_piecepacks_expansion = packs$dpe,
+         go = go(1, color_list),
+         hexpack = packs$hexpack,
+         meeples = meeples(color_list),
+         piecepack = packs$base,
+         playing_cards = cards$base,
+         playing_cards_colored = cards$color,
+         playing_cards_tarot = cards$tarot,
+         playing_cards_expansion = packs$pce,
+         subpack = packs$subpack)
+}
 
-    dpe_base <- c(invert_colors.suited=TRUE,
-                  mat_color.tile_face="white", mat_width.tile_face=0.05,
-                  border_color.s2.die="grey40", border_color.s2.pawn="grey40")
-
-    dual_piecepacks_expansion <- c(piecepack, dpe_base)
-    dual_piecepacks_expansion$suit_text <- pce_suit_text
+cb_suit_colors_impure <- c("#D55E00", "grey30", "#009E73", "#56B4E9", "#E69F00", "#FFFFFF")
+cb_suit_colors_pure <- c("#D55E00", "#000000", "#009E73", "#56B4E9", "#E69F00", "#FFFFFF")
 
+dice <- function(color_list, rect_shape) {
     dice_list <- list(n_suits = 6, n_ranks = 6,
                       rank_text = "1,2,3,4,5,6",
                       width.die = 16 / 25.4, # 16 mm dice most common
@@ -193,56 +163,10 @@ game_systems <- function(style=NULL, round = FALSE, pawn="token") {
     dice <- pp_cfg(c(dice_list, color_list))
     dice$has_piecepack <- FALSE
     dice$has_dice <- TRUE
+    dice
+}
 
-    playing_cards_list <- list(n_ranks = 14,
-                               rank_text = "A,2,3,4,5,6,7,8,9,10,J,Q,K,\n\n\n\nJ\nO\nK\nE\nR",
-                               grob_fn.card = cardGrobFn(),
-                               grob_fn.r11.card = faceCardGrobFn(face_labels[1]),
-                               grob_fn.r12.card = faceCardGrobFn(face_labels[3]),
-                               grob_fn.r13.card = faceCardGrobFn(face_labels[4]),
-                               grob_fn.r14.card = jokerCardGrobFn(TRUE),
-                               shape.card = rect_shape,
-                               border_color = "black", border_lex = 4)
-    playing_cards_list$n_suits <- 4
-    playing_cards_list$suit_color <- "#D55E00,#000000,#000000,#D55E00,#E59F00"
-
-    playing_cards <- c(playing_cards_list, pc_suit_text)
-    playing_cards$grob_fn.s3.r14.card <- jokerCardGrobFn(FALSE)
-    playing_cards$grob_fn.s4.r14.card <- jokerCardGrobFn(FALSE)
-    playing_cards <- pp_cfg(playing_cards)
-    playing_cards$has_piecepack <- FALSE
-    playing_cards$has_cards <- TRUE
-
-    playing_cards_colored <- c(playing_cards_list, pc_suit_text)
-    playing_cards_colored$n_suits <- 5
-    playing_cards_colored$suit_color <- cb_suit_colors_pure
-
-    playing_cards_colored <- pp_cfg(playing_cards_colored)
-    playing_cards_colored$has_piecepack <- FALSE
-    playing_cards_colored$has_cards <- TRUE
-
-    playing_cards_tarot <- playing_cards_list
-    playing_cards_tarot$rank_text <- "A,2,3,4,5,6,7,8,9,10,J,C,Q,K,\n\n\n\nJ\nO\nK\nE\nR"
-    playing_cards_tarot$grob_fn.r12.card <- faceCardGrobFn(face_labels[2], "low")
-    playing_cards_tarot$grob_fn.r13.card <- faceCardGrobFn(face_labels[3])
-    playing_cards_tarot$grob_fn.r14.card <- faceCardGrobFn(face_labels[4])
-    playing_cards_tarot$grob_fn.r15.card <- jokerCardGrobFn(TRUE)
-    playing_cards_tarot$grob_fn.s3.r15.card <- jokerCardGrobFn(FALSE)
-    playing_cards_tarot$grob_fn.s4.r15.card <- jokerCardGrobFn(FALSE)
-    fool_text <- ifelse(grepl("dejavu", style), "\u2605", "*")
-    playing_cards_tarot$rank_text.s5 <- c(1:21, fool_text)
-    playing_cards_tarot$n_suits <- 5
-    playing_cards_tarot$n_ranks <- 22
-
-    tarot_suit_text <- "\u2665,\u2660,\u2663,\u2666,"
-    playing_cards_tarot$suit_text <- tarot_suit_text
-    playing_cards_tarot$suit_text.r14 <- tarot_suit_text
-    playing_cards_tarot$suit_color <- "#D55E00,#000000,#000000,#D55E00,#000000"
-    playing_cards_tarot$grob_fn.s5.card <- cardGrobFn(0)
-    playing_cards_tarot <- pp_cfg(playing_cards_tarot)
-    playing_cards_tarot$has_piecepack <- FALSE
-    playing_cards_tarot$has_cards <- TRUE
-
+meeples <- function(color_list) {
     meeples_list <- list(shape.bit = "meeple", n_suits = 6,
                          width.bit = 16 / 25.4, height.bit = 16 / 25.4, depth.bit = 10 / 25.4,
                          ps_text.bit = "", dm_text.bit = "",
@@ -250,34 +174,9 @@ game_systems <- function(style=NULL, round = FALSE, pawn="token") {
     meeples <- pp_cfg(c(meeples_list, color_list))
     meeples$has_piecepack <- FALSE
     meeples$has_bits <- TRUE
-
-    list(checkers1 = checkers(1, color_list),
-         checkers2 = checkers(2, color_list),
-         chess1 = chess(1, color_list, chess_black, chess_white),
-         chess2 = chess(2, color_list, chess_black, chess_white),
-         dice = dice,
-         dominoes = dominoes(color_list$suit_color[6], "black", color_list$border_color, rect_shape),
-         dominoes_black = dominoes(color_list$suit_color[2], "white", color_list$border_color, rect_shape),
-         dominoes_blue = dominoes(color_list$suit_color[4], "white", color_list$border_color, rect_shape),
-         dominoes_green = dominoes(color_list$suit_color[3], "white", color_list$border_color, rect_shape),
-         dominoes_red = dominoes(color_list$suit_color[1], "white", color_list$border_color, rect_shape),
-         dominoes_white = dominoes(color_list$suit_color[6], "black", color_list$border_color, rect_shape),
-         dominoes_yellow = dominoes(color_list$suit_color[5], "black", color_list$border_color, rect_shape),
-         dual_piecepacks_expansion = pp_cfg(dual_piecepacks_expansion),
-         go = go(1, color_list),
-         hexpack = to_hexpack(piecepack),
-         meeples = meeples,
-         piecepack = pp_cfg(piecepack),
-         playing_cards = playing_cards,
-         playing_cards_colored = playing_cards_colored,
-         playing_cards_tarot = playing_cards_tarot,
-         playing_cards_expansion = pp_cfg(playing_cards_expansion),
-         subpack = to_subpack(piecepack))
+    meeples
 }
 
-cb_suit_colors_impure <- c("#D55E00", "grey30", "#009E73", "#56B4E9", "#E69F00", "#FFFFFF")
-cb_suit_colors_pure <- c("#D55E00", "#000000", "#009E73", "#56B4E9", "#E69F00", "#FFFFFF")
-
 dominoes <- function(background_color = "white", suit_color = "black", border_color = "black",
                      rect_shape, mat_width = 0) {
     border_lex <- ifelse(border_color == "black", 4, 0)
@@ -332,7 +231,14 @@ checkers <- function(cell_width = 1, color_list) {
     checkers
 }
 
-chess <- function(cell_width = 1, color_list, black_chess_ranks, white_chess_ranks) {
+chess <- function(style, cell_width = 1, color_list) {
+    if (grepl("^sans", style)) {
+        black_chess_ranks <- c("p", "n", "b", "r", "q", "k")
+        white_chess_ranks <- c("P", "N", "B", "R", "Q", "K")
+    } else if (grepl("^dejavu", style)) {
+        black_chess_ranks <- c("\u265f", "\u265e", "\u265d", "\u265c", "\u265b", "\u265a")
+        white_chess_ranks <- c("\u2659", "\u2658", "\u2657", "\u2656", "\u2655", "\u2654")
+    }
     chess <- list(n_suits = 6, n_ranks = 12,
                      width.board = 8 * cell_width,
                      height.board = 8 * cell_width,
@@ -397,6 +303,192 @@ go <- function(cell_width = 1, color_list) {
     go
 }
 
+piecepack <- function(style, color_list, rect_shape, pawn) {
+    if (grepl("^sans", style)) {
+        piecepack_suits <- list(suit_text="\u263c,\u25d8,\u0238,\u03ee,\u2202")
+        pce_suit_text <- "\u2665,\u2660,\u2663,\u2666,\u2202"
+    } else if (grepl("^dejavu", style)) {
+        piecepack_suits <- list(suit_text="\u2742,\u25d0,\u265b,\u269c,\u0ed1",
+                                suit_cex.s2=0.9, dm_cex.coin=0.5, fontfamily="DejaVu Sans")
+        pce_suit_text <- "\u2665,\u2660,\u2663,\u2666,\u0ed1"
+    }
+    is_3d <- grepl("3d$", style)
+    if (is_3d) {
+        style_3d <- list(suit_color.s4 = "#0072B2",
+                         invert_colors.pawn = TRUE,
+                         invert_colors.die = TRUE,
+                         background_color.die = "white",
+                         border_color="transparent",
+                         mat_color.tile_back = "burlywood",
+                         edge_color.tile = "black", edge_color.coin = "black",
+                         border_color.pyramid="black", border_lex.pyramid=1, background_color.pyramid="white")
+    } else {
+        style_3d <- NULL
+    }
+    piecepack_base <- list(depth.coin=0.25,
+                           invert_colors.matchstick = TRUE,
+                           ps_cex.r2.matchstick = 0.7,
+                           dm_r.r1.matchstick = 0, dm_cex.r1.matchstick = 1.5, suit_color.s2.matchstick = "grey30",
+                           mat_color.tile_back="white", mat_width.tile_back=0.05, suit_color.unsuited="black",
+                           invert_colors.bit = TRUE,
+                           rank_text=",a,2,3,4,5",
+                           use_suit_as_ace=TRUE,
+                           rank_text.pyramid=LETTERS[1:6],
+                           suit_cex.pyramid_face=0.5, ps_r.pyramid_face=-0.08,
+                           dm_cex.pyramid_face=4.0, dm_text.pyramid_face="|", dm_r.pyramid_face=-0.22,
+                           ps_cex.pyramid_left=0.7, ps_r.pyramid_left=-0.00,
+                           ps_cex.pyramid_right=0.7, ps_r.pyramid_right=-0.00,
+                           use_suit_as_ace.pyramid=FALSE,
+                           shape.tile = rect_shape, shape.card = rect_shape)
+    shapes <- shapes_cfg(color_list)
+    pawn <- switch(pawn,
+                   "peg-doll" = peg_doll_pawn(shapes),
+                   "joystick" = joystick_pawn(shapes),
+                   NULL)
+    piecepack <- c(pawn, style_3d, piecepack_suits, color_list, piecepack_base)
+
+    playing_cards_expansion <- piecepack
+    playing_cards_expansion$suit_text <- pce_suit_text
+    playing_cards_expansion$suit_color <- "#D55E00,#000000,#000000,#D55E00,#000000"
+
+    hexpack <- c(piecepack, list(shape.tile="convex6", border_lex=3,
+                                 shape_t.tile="60",  dm_t.tile_face=-90,
+                                 width.tile=4/sqrt(3), height.tile=4/sqrt(3),
+                                 shape.coin="convex3"))
+
+    dpe_base <- c(invert_colors.suited=TRUE,
+                  mat_color.tile_face="white", mat_width.tile_face=0.05,
+                  border_color.s2.die="grey40", border_color.s2.pawn="grey40")
+
+    dual_piecepacks_expansion <- c(piecepack, dpe_base)
+    dual_piecepacks_expansion$suit_text <- pce_suit_text
+
+    list(base = pp_cfg(piecepack),
+         dpe = pp_cfg(dual_piecepacks_expansion),
+         hex = to_hexpack(piecepack),
+         pce = pp_cfg(playing_cards_expansion),
+         subpack = to_subpack(piecepack))
+}
+
+playing_cards <- function(style, rect_shape) {
+    if (grepl("^sans", style)) {
+        face_labels <- c("", "\u050a", "\u046a", "\u0238")
+        fool_text <- "*"
+        pc_suit_text <- list(suit_text="\u2665,\u2660,\u2663,\u2666,*",
+                             suit_cex.s5=1.3)
+    } else if (grepl("^dejavu", style)) {
+        face_labels <- c("", "\u265e", "\u265b", "\u265a")
+        fool_text <- "\u2605"
+        pc_suit_text <- list(suit_text="\u2665,\u2660,\u2663,\u2666,\u2605")
+    }
+
+    playing_cards_list <- list(n_ranks = 14,
+                               rank_text = "A,2,3,4,5,6,7,8,9,10,J,Q,K,\n\n\n\nJ\nO\nK\nE\nR",
+                               grob_fn.card = cardGrobFn(),
+                               grob_fn.r11.card = faceCardGrobFn(face_labels[1]),
+                               grob_fn.r12.card = faceCardGrobFn(face_labels[3]),
+                               grob_fn.r13.card = faceCardGrobFn(face_labels[4]),
+                               grob_fn.r14.card = jokerCardGrobFn(TRUE),
+                               shape.card = rect_shape,
+                               border_color = "black", border_lex = 4)
+    playing_cards_list$n_suits <- 4
+    playing_cards_list$suit_color <- "#D55E00,#000000,#000000,#D55E00,#E59F00"
+
+    playing_cards <- c(playing_cards_list, pc_suit_text)
+    playing_cards$grob_fn.s3.r14.card <- jokerCardGrobFn(FALSE)
+    playing_cards$grob_fn.s4.r14.card <- jokerCardGrobFn(FALSE)
+    playing_cards <- pp_cfg(playing_cards)
+    playing_cards$has_piecepack <- FALSE
+    playing_cards$has_cards <- TRUE
+
+    playing_cards_colored <- c(playing_cards_list, pc_suit_text)
+    playing_cards_colored$n_suits <- 5
+    playing_cards_colored$suit_color <- cb_suit_colors_pure
+
+    playing_cards_colored <- pp_cfg(playing_cards_colored)
+    playing_cards_colored$has_piecepack <- FALSE
+    playing_cards_colored$has_cards <- TRUE
+
+    playing_cards_tarot <- playing_cards_list
+    playing_cards_tarot$rank_text <- "A,2,3,4,5,6,7,8,9,10,J,C,Q,K,\n\n\n\nJ\nO\nK\nE\nR"
+    playing_cards_tarot$grob_fn.r12.card <- faceCardGrobFn(face_labels[2], "low")
+    playing_cards_tarot$grob_fn.r13.card <- faceCardGrobFn(face_labels[3])
+    playing_cards_tarot$grob_fn.r14.card <- faceCardGrobFn(face_labels[4])
+    playing_cards_tarot$grob_fn.r15.card <- jokerCardGrobFn(TRUE)
+    playing_cards_tarot$grob_fn.s3.r15.card <- jokerCardGrobFn(FALSE)
+    playing_cards_tarot$grob_fn.s4.r15.card <- jokerCardGrobFn(FALSE)
+    playing_cards_tarot$rank_text.s5 <- c(1:21, fool_text)
+    playing_cards_tarot$n_suits <- 5
+    playing_cards_tarot$n_ranks <- 22
+
+    tarot_suit_text <- "\u2665,\u2660,\u2663,\u2666,"
+    playing_cards_tarot$suit_text <- tarot_suit_text
+    playing_cards_tarot$suit_text.r14 <- tarot_suit_text
+    playing_cards_tarot$suit_color <- "#D55E00,#000000,#000000,#D55E00,#000000"
+    playing_cards_tarot$grob_fn.s5.card <- cardGrobFn(0)
+    playing_cards_tarot <- pp_cfg(playing_cards_tarot)
+    playing_cards_tarot$has_piecepack <- FALSE
+    playing_cards_tarot$has_cards <- TRUE
+
+    list(base = playing_cards, color = playing_cards_colored, tarot = playing_cards_tarot)
+}
+
+shapes_cfg <- function(color_list) {
+    shapes <- list(n_suits = 6, n_ranks = 4,
+                   invert_colors = TRUE,
+                   ps_text = "", dm_text = "",
+                   background_color = "white",
+                   width = 1, height = 1, depth = 1,
+                   shape.r1.bit = "circle",
+                   shape.r2.bit = "circle",
+                   op_grob_fn.r2.bit = basicEllipsoid,
+                   obj_fn.r2.bit = function(...) save_ellipsoid_obj(..., subdivide=4),
+                   shape.r3.bit = "pyramid",
+                   shape.r4.bit = "rect")
+    pp_cfg(c(shapes, color_list))
+}
+
+peg_doll_pawn <- function(shapes) {
+
+    pegdoll_depth <- c(0.55, 1.0 * 0.75 / 1.5)
+    df_pegdoll <- tibble(piece_side = "bit_back", rank = c(1, 2),
+                          width =  1, height = 1, depth = pegdoll_depth,
+                          x = 0.5, y = 0.5, z = c(0.5 * pegdoll_depth[1], 1 - 0.5 * pegdoll_depth[2]),
+                          cfg = "shapes")
+
+    pegdoll <- CompositePiece$new(df_pegdoll, envir=list(shapes=shapes))
+
+    list(width.pawn=0.75, depth.pawn=0.75, height.pawn=1.5,
+         edge_color.pawn=cb_suit_colors_pure,
+         edge_color.s4.pawn="#0072B2",
+         background_color.belt_face="white",
+         mat_color.belt_face="transparent",
+         suit_cex.belt_face=1.5,
+         obj_fn.pawn=save_peg_doll_obj,
+         grob_fn.pawn = pegdoll$grob_fn,
+         op_grob_fn.pawn = pegdoll$op_grob_fn)
+}
+
+joystick_pawn <- function(shapes) {
+
+    jd <- c(0.15, 0.6, 0.5 * 5 / 8)
+    df_joystick <- tibble(piece_side = "bit_back", rank = c(1, 1, 2),
+                          width =  c(1, 0.3, 0.5),
+                          height = c(1, 0.3, 0.5),
+                          depth = jd,
+                          x = rep(0.5, 3), y = rep(0.5, 3),
+                          z = c(0.5 * jd[1], jd[1] + 0.5 * jd[2], 1 - 0.5 * jd[3]),
+                          cfg = "shapes")
+
+    joystick <- CompositePiece$new(df_joystick, envir=list(shapes=shapes))
+
+    list(grob_fn.pawn = joystick$grob_fn,
+         op_grob_fn.pawn = joystick$op_grob_fn,
+         rayrender_fn.pawn = joystick$rayrender_fn,
+         rgl_fn.pawn = joystick$rgl_fn,
+         width.pawn=5/8, height.pawn=1.0, depth.pawn=5/8)
+}
+
 #' @rdname game_systems
 #' @export
 to_hexpack <- function(cfg=pp_cfg()) {
